"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBitloopsFilesAndContents = void 0;
/**
 *  Bitloops Language CLI
 *  Copyright (C) 2022 Bitloops S.A.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 *  For further information you can contact legal(at)bitloops.com.
 */
const fs = require("fs/promises");
const path = require("path");
const getRecursivelyFileInDirectory_js_1 = require("./getRecursivelyFileInDirectory.js");
const BL_SUFFIX = 'bl';
const getBitloopsFilesAndContents = async (boundedContextModules, sourceDirPath) => {
    const result = [];
    for (const [boundedContextName, modules] of Object.entries(boundedContextModules)) {
        for (const moduleName of modules) {
            const modulePath = path.join(sourceDirPath, boundedContextName, moduleName);
            const contextFilePaths = (0, getRecursivelyFileInDirectory_js_1.getRecursivelyFileInDirectory)(modulePath, BL_SUFFIX);
            const moduleInput = await Promise.all(contextFilePaths.map(async (contextFilePath) => {
                const fileContents = await fs.readFile(contextFilePath, 'utf-8');
                const fileName = contextFilePath.split('/').pop();
                return {
                    boundedContext: boundedContextName,
                    module: moduleName,
                    fileId: contextFilePath,
                    fileName,
                    fileContents,
                };
            }));
            result.push(...moduleInput);
        }
    }
    return result;
};
exports.getBitloopsFilesAndContents = getBitloopsFilesAndContents;
//# sourceMappingURL=readFilesContents.js.map