"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyFile = exports.getFilename = exports.ensureDirectoryExistence = exports.readFromFile = exports.prependToFile = exports.writeToFile = exports.clearFolder = void 0;
/**
 *  Bitloops Language CLI
 *  Copyright (C) 2022 Bitloops S.A.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 *  For further information you can contact legal(at)bitloops.com.
 */
const fs_1 = require("fs");
const path_1 = require("path");
const FILE_SUFFIX_DELIMITER = '.';
const FOLDER_DELIMITER = '/';
const ensureDirectoryExistence = (filePath) => {
    const dirname = path_1.default.dirname(filePath);
    if (fs_1.default.existsSync(dirname)) {
        return true;
    }
    ensureDirectoryExistence(dirname);
    fs_1.default.mkdirSync(dirname);
};
exports.ensureDirectoryExistence = ensureDirectoryExistence;
const writeToFile = (data, filePath) => {
    ensureDirectoryExistence(filePath);
    // console.log('trying to write to file', filePath);
    fs_1.default.writeFileSync(filePath, data);
};
exports.writeToFile = writeToFile;
const readFromFile = (filePath) => {
    if (!fs_1.default.existsSync(filePath)) {
        return null;
    }
    return fs_1.default.readFileSync(filePath, 'utf8');
};
exports.readFromFile = readFromFile;
const prependToFile = (data, filePath) => {
    const fileData = fs_1.default.readFileSync(filePath);
    const prependByteData = Buffer.from(data);
    const fd = fs_1.default.openSync(filePath, 'w+');
    fs_1.default.writeSync(fd, prependByteData, 0, prependByteData.length, 0);
    fs_1.default.writeSync(fd, fileData, 0, fileData.length, prependByteData.length);
    fs_1.default.closeSync(fd);
};
exports.prependToFile = prependToFile;
const getFilename = (filePath) => {
    const filenameParts = filePath.split(FILE_SUFFIX_DELIMITER);
    const fileNameWithoutSuffix = filenameParts[filenameParts.length - 2];
    const filePathNames = fileNameWithoutSuffix.split(FOLDER_DELIMITER);
    const fileName = filePathNames[filePathNames.length - 1];
    return fileName;
};
exports.getFilename = getFilename;
const copyFile = (source, dest) => {
    fs_1.default.copyFileSync(source, dest);
};
exports.copyFile = copyFile;
const clearFolder = (outputDirPath) => {
    fs_1.default.rmSync(path_1.default.normalize(`${outputDirPath}/src`), {
        recursive: true,
        force: true,
    });
};
exports.clearFolder = clearFolder;
//# sourceMappingURL=fileOperations.js.map