#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 *  Bitloops Language CLI
 *  Copyright (C) 2022 Bitloops S.A.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 *  For further information you can contact legal(at)bitloops.com.
 */
const commander_1 = require("commander");
const chalk_1 = require("chalk");
const figlet_1 = require("figlet");
const axios_1 = require("axios");
const transpile_js_1 = require("./commands/transpile.js");
const copyright_js_1 = require("./commands/copyright.js");
const VERSION_CHECK_URL = 'https://bitloops-language-version-check-6en3sbe4da-uc.a.run.app';
const CURRENT_VERSION = process.env.npm_package_version || '0.2.1';
// Check if current version is the latest
const checkVersion = async () => {
    return await axios_1.default
        .post(VERSION_CHECK_URL, { version: CURRENT_VERSION })
        .then((res) => {
        const latestVersion = res.data.version;
        const latestVersionArray = latestVersion.split('.');
        const currentVersionArray = CURRENT_VERSION.split('.');
        if (Number(latestVersionArray[0]) > Number(currentVersionArray[0]) ||
            Number(latestVersionArray[1]) > Number(currentVersionArray[1]) ||
            Number(latestVersionArray[2]) > Number(currentVersionArray[2])) {
            console.log(chalk_1.default.yellow('A new version of the Bitloops Language CLI is available: ') +
                chalk_1.default.green(`v${latestVersion}`));
            console.log(chalk_1.default.yellow('To update run:'));
            console.log(chalk_1.default.yellow('npm install -g @bitloops/bitloops-language-cli'));
            console.log('or');
            console.log(chalk_1.default.yellow('yarn global add @bitloops/bitloops-language-cli'));
        }
    })
        .catch((err) => {
        console.error(err);
    });
};
(async () => {
    try {
        await checkVersion();
        const program = new commander_1.Command();
        const purpleColor = chalk_1.default.hex('#7700e5');
        console.log(purpleColor(figlet_1.default.textSync('BL', { horizontalLayout: 'default' })));
        console.log(purpleColor('Bitloops Language'));
        program.version(`v${CURRENT_VERSION}`).description('The Bitloops Language CLI');
        program.summary('The Bitloops Language CLI is a command line utility for transpiling Bitloops Language files into your preferred target language (currently only TypeScript is supported).');
        program.description(copyright_js_1.copyrightSnippet);
        program
            .command('transpile')
            .description('Transpile a BL project')
            .option('-l, --targetLanguage <string>')
            .option('-s, --sourceDirPath <string>')
            .option('-t, --targetDirPath <string>')
            .action(transpile_js_1.default);
        program.command('copyright').description('Print copyright information').action(copyright_js_1.default);
        program.parse(process.argv);
    }
    catch (e) {
        console.error(e);
    }
})();
//# sourceMappingURL=index.js.map